import {
  config
} from '@/common/config.js';
import store from '../store/index.js'

// 这里的vm，就是我们在vue文件里面的this，所以我们能在这里获取vuex的变量，比如存放在里面的token
// 同时，我们也可以在此使用getApp().globalData，如果你把token放在getApp().globalData的话，也是可以使用的
const install = (Vue, vm) => {
  Vue.prototype.$u.http.setConfig({
    baseUrl: config.baseUrl,
		// 设置为json，返回后会对数据进行一次JSON.parse()
		dataType: 'json',
		showLoading: true, // 是否显示请求中的loading
		loadingText: '请求中...', // 请求loading中的文字提示
		loadingTime: 500, // 在此时间内，请求还没回来的话，就显示加载中动画，单位ms
		originalData: false, // 是否在拦截器中返回服务端的原始数据
		loadingMask: true, // 展示loading的时候，是否给一个透明的蒙层，防止触摸穿透
		// 配置请求头信息
		header: {
			'content-type': 'application/json;charset=UTF-8'
		}
  });
  // 请求拦截，配置Token等参数
  Vue.prototype.$u.http.interceptor.request = (config) => {

    if (vm.vuex_token) {
      config.header.Authorization = `Bearer ${vm.vuex_token}`;
    }
    // url加时间戳
    config.url = config.url + '?t=' + Date.now()
    let noTokenList = ['/wechat/h5/user', '/client/auth/verifyCode'];
    if (noTokenList.includes(config.url)) config.header.noToken = true;
    return config;
  }
  // 响应拦截，判断状态码是否通过
  Vue.prototype.$u.http.interceptor.response = (res) => {
    if (res.code == 200) {
      return res;
    } else if (res.msg == "令牌不能为空" || res.code == 401) {
      const backUrl = location.href
      const loginUrl = 'phoneLogin'
      if (backUrl.indexOf(loginUrl) > 0) {} else {
        localStorage.setItem('backUrl', location.href)
        store.state.vuex_hasLogin = false;
        alert('还未登录,即将跳转登录');
        uni.navigateTo({
          url: "/pages/phoneLogin/phoneLogin"
        });
        return;
      }
    } else {
			uni.showToast({
				title: res.msg,
				icon: 'none',
				duration: 2000
			})
		}
  }
}

export default {
  install
}
